import type { ViteDevServer } from 'vite';
import type { AstroSettings, ComponentInstance, RouteData, RuntimeMode, SSRLoadedRenderer } from '../../../@types/astro';
import { LogOptions } from '../../logger/core.js';
import { RouteCache } from '../route-cache.js';
import type { DevelopmentEnvironment } from './environment';
export { createDevelopmentEnvironment } from './environment.js';
export type { DevelopmentEnvironment };
export interface SSROptionsOld {
    /** an instance of the AstroSettings */
    settings: AstroSettings;
    /** location of file on disk */
    filePath: URL;
    /** logging options */
    logging: LogOptions;
    /** "development" or "production" */
    mode: RuntimeMode;
    /** production website */
    origin: string;
    /** the web request (needed for dynamic routes) */
    pathname: string;
    /** optional, in case we need to render something outside of a dev server */
    route?: RouteData;
    /** pass in route cache because SSR can’t manage cache-busting */
    routeCache: RouteCache;
    /** Vite instance */
    viteServer: ViteDevServer;
    /** Request */
    request: Request;
}
export interface SSROptions {
    /** The environment instance */
    env: DevelopmentEnvironment;
    /** location of file on disk */
    filePath: URL;
    /** production website */
    origin: string;
    /** the web request (needed for dynamic routes) */
    pathname: string;
    /** The renderers and instance */
    preload: ComponentPreload;
    /** Request */
    request: Request;
    /** optional, in case we need to render something outside of a dev server */
    route?: RouteData;
}
export declare type ComponentPreload = [SSRLoadedRenderer[], ComponentInstance];
export declare function loadRenderers(viteServer: ViteDevServer, settings: AstroSettings): Promise<SSRLoadedRenderer[]>;
export declare function preload({ env, filePath, }: Pick<SSROptions, 'env' | 'filePath'>): Promise<ComponentPreload>;
export declare function renderPage(options: SSROptions): Promise<Response>;
